@@ -28,5 +28,5 @@ void
 LogPulseError(pa_context *context, const char *prefix) noexcept
 {
 	const int e = pa_context_errno(context);
-	FormatError(pulse_domain, "%s: %s", prefix, pa_strerror(e));
+	FmtError(pulse_domain, "{}: {}", prefix, pa_strerror(e));
 }
