@@ -99,7 +99,7 @@ void
 SmbclientNeighborExplorer::Close() noexcept
 {
 	{
-		const std::lock_guard<Mutex> lock(mutex);
+		const std::scoped_lock<Mutex> lock(mutex);
 		quit = true;
 		cond.notify_one();
 	}
@@ -110,7 +110,7 @@ SmbclientNeighborExplorer::Close() noexcept
 NeighborExplorer::List
 SmbclientNeighborExplorer::GetList() const noexcept
 {
-	const std::lock_guard<Mutex> protect(mutex);
+	const std::scoped_lock<Mutex> protect(mutex);
 	return list;
 }
 
