@@ -27,22 +27,15 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "config.h"
 #include "StaticSocketAddress.hxx"
+#include "IPv4Address.hxx"
+#include "IPv6Address.hxx"
 #include "util/StringView.hxx"
 
 #include <algorithm>
 
 #include <string.h>
 
-#ifdef HAVE_TCP
-#ifdef _WIN32
-#include <ws2tcpip.h>
-#else
-#include <netinet/in.h>
-#endif
-#endif
-
 StaticSocketAddress &
 StaticSocketAddress::operator=(SocketAddress other) noexcept
 {
@@ -69,15 +62,15 @@ StaticSocketAddress::SetPort(unsigned port) noexcept
 	switch (GetFamily()) {
 	case AF_INET:
 		{
-			auto &a = (struct sockaddr_in &)address;
-			a.sin_port = htons(port);
+			auto &a = *(IPv4Address *)(void *)&address;
+			a.SetPort(port);
 			return true;
 		}
 
 	case AF_INET6:
 		{
-			auto &a = (struct sockaddr_in6 &)address;
-			a.sin6_port = htons(port);
+			auto &a = *(IPv6Address *)(void *)&address;
+			a.SetPort(port);
 			return true;
 		}
 	}
